@@ -558,7 +558,7 @@ featureset_ptr ogr_datasource::features(query const& q) const
         }
     }
 
-    return mapnik::make_invalid_featureset();
+    return mapnik::make_empty_featureset();
 }
 
 featureset_ptr ogr_datasource::features_at_point(coord2d const& pt, double tol) const
@@ -595,5 +595,5 @@ featureset_ptr ogr_datasource::features_at_point(coord2d const& pt, double tol)
         }
     }
 
-    return mapnik::make_invalid_featureset();
+    return mapnik::make_empty_featureset();
 }
