@@ -1,7 +1,8 @@
 #ifndef TEST_MEMORY_CLEANUP
 #define TEST_MEMORY_CLEANUP
 
-#pragma GCC diagnostic push
+#include <mapnik/warning.hpp>
+MAPNIK_DISABLE_WARNING_PUSH
 #include <mapnik/warning_ignore.hpp>
 
 #if defined(HAVE_LIBXML2)
@@ -15,11 +16,8 @@
 #endif
 
 #include <unicode/uclean.h>
-#ifdef MAPNIK_USE_PROJ4
-#include <proj_api.h>
-#endif
 
-#pragma GCC diagnostic pop
+MAPNIK_DISABLE_WARNING_POP
 
 namespace testing {
 
@@ -46,17 +44,8 @@ inline void run_cleanup()
 
     // http://icu-project.org/apiref/icu4c/uclean_8h.html#a93f27d0ddc7c196a1da864763f2d8920
     u_cleanup();
-
-#ifdef MAPNIK_USE_PROJ4
-    // http://trac.osgeo.org/proj/ticket/149
- #if PJ_VERSION >= 480
-    pj_clear_initcache();
- #endif
-    // https://trac.osgeo.org/proj/wiki/ProjAPI#EnvironmentFunctions
-    pj_deallocate_grids();
-#endif
 }
 
-}
+} // namespace testing
 
 #endif
